# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key: pypi-AgEIcHlwaS5vcmcCJDQwY2FiYzc5LTBiMTAtNDViMS1iZTZjLTYyMzhhZmViNzI2MQACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiDDxh9zWY_04kfjz4oO-go-e2w9LsRpNX0veVp_qlcdCw

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/